@@ -431,8 +431,11 @@ class TermLintReport(LintReport):
 
         if diagnostic_result.result_state == LintDiagnosticResultState.FIXABLE:
             has_fixit = " [Correctable via --auto-fix]"
+
+        code = f"[{diagnostic.code}]: " if diagnostic.code else ""
+        msg = f"{code}{diagnostic.message}"
         print(
-            f"{tag}: File: {filename}:{start_line+1}:{start_position}:{end_line+1}:{end_position}: {diagnostic.message}{has_fixit}",
+            f"{tag}: File: {filename}:{start_line+1}:{start_position}:{end_line+1}:{end_position}: {msg}{has_fixit}",
         )
         if diagnostic_result.missing_severity:
             _warn(
